#include <iostream>
#include <vector>
#include <map>

constexpr int N = 10000;

void sieve(int maxp, std::vector<int> &primes)
{
    if(2 <= maxp)
        primes.push_back(2);
    std::vector<bool> visited(maxp+1);
    for(int i=3; i<=maxp; i+=2)
    {
        if(!visited[i])
        {
            primes.push_back(i);
            for(int j=i*i; j<=maxp; j+=i)
            {
                visited[j] = true;
            }
        }
    }
}

void factor(int64_t number, const std::vector<int> &primes, std::vector<std::pair<int, int> > &factors)
{
    for(auto p : primes)
    {
        if(number % p == 0)
        {
            int power = 0;
            while(number % p == 0)
            {
                number /= p;
                power++;
            }
            factors.push_back({p, power});
        }
    }
}

void addTotientTerms(int prime, const std::vector<int> &primes, std::map<int, int> &primemap, std::vector<int> &coefficients)
{
    int k = prime-1;
    std::vector<std::pair<int, int> > kfactors;
    factor(k, primes, kfactors);
    for(auto it : kfactors)
    {
        coefficients[primemap[it.first]] += it.second;
    }
}

int main()
{
    std::vector<int> primes;
    sieve(N, primes);
    int np = primes.size();
    std::map<int, int> primemap;
    for(int i=0; i<np; i++)
        primemap[primes[i]] = i;
    
    int inputs[2];
    std::cin >> inputs[0] >> inputs[1];
    std::vector<int> inputfactors[2];
    std::vector<int> outputfactors[2];
    for(int i=0; i<2; i++)
    {
        inputfactors[i].resize(np);
        outputfactors[i].resize(np);
        std::vector<std::pair<int, int> > factors;
        factor(inputs[i], primes, factors);
        for(auto it : factors)
        {
            inputfactors[i][primemap[it.first]] = it.second;
        }
    }
    for(int i=np-1; i>=0; i--)
    {
        if(inputfactors[0][i] > 0 && inputfactors[1][i] > 0)
        {
            int common = std::min(inputfactors[0][i], inputfactors[1][i]);
            inputfactors[0][i] -= common;
            inputfactors[1][i] -= common;
        }
        for(int term=0; term<2; term++)
        {
            int otherterm = 1-term;
            if(inputfactors[term][i] > 0)
            {
                int power1 = 1 + inputfactors[term][i]/2;
                int power2 = ((inputfactors[term][i] % 2) ? 0 : 1);
                outputfactors[term][i] += power1;
                outputfactors[otherterm][i] += power2;
                if(power2 == 0)
                    addTotientTerms(primes[i], primes, primemap, inputfactors[otherterm]);
                inputfactors[term][i] = 0;
            }
        }
    }
    int64_t outputs[2];
    outputs[0] = outputs[1] = 1;
    for(int i=0; i<np; i++)
    {
        for(int term=0; term<2; term++)
        {
            for(int k=0; k<outputfactors[term][i]; k++)
            {
                outputs[term] *= int64_t(primes[i]);
            }
        }
    }
    std::cout << outputs[0] << " " << outputs[1] << std::endl;
}
