#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <ctype.h>
#include <math.h>

typedef unsigned long DWORD;
typedef unsigned short WORD;
typedef unsigned char BYTE;
typedef unsigned long long DDWORD;

#undef DEBUG
#define MAX_INPUT 10000
#define MAX_PRIMES 10000
#define NUM 0
#define DEN	1

typedef struct _pPowfract_
{
	struct _pPowfract_ *pPrev;
	struct _pPowfract_ *pNext;
	int prime;
	short pows[2];
} PPOWFRACT, *PPPOWFRACT;

typedef struct _powFract_ 
{
	PPPOWFRACT pFirst;
	PPPOWFRACT pLast;
	int firstPrime;
	int lastPrime;
} POW_FRACT, *PPOW_FRACT;

PPPOWFRACT FreePow;
PPOWFRACT powFracts[MAX_PRIMES];
POW_FRACT inFract, workFract, outFract, valFract;

int a, b, maxin;
DDWORD m, n, mask;
WORD leastFact[MAX_INPUT+1];

int GCD(int a, int b)
{
	int c;
	if(b == 0) return a;
	while(b != 0) {
		c = a%b;
		a = b; b = c;
	}
	return a;
}

PPPOWFRACT NewPowFract()
{
	PPPOWFRACT pRes = FreePow;
	if(pRes != NULL) {
		FreePow = pRes->pNext;
		return pRes;
	}
	return NULL;
}

void ReleasePowFract(PPPOWFRACT pPFract)
{
	pPFract ->pNext = FreePow;
	FreePow = pPFract;
}

void FactorSetup()
{
	int i, j;
	PPPOWFRACT pCur, pPrev;
	memset(&(leastFact[0]), 0, (maxin + 1)*sizeof(WORD));
	leastFact[0] = leastFact[1] = 1;
	for(i = 2; i <= maxin ; i++) {
		if(leastFact[i] == 0) {
			for(j = i; j <= maxin; j+= i) {
				 if(leastFact[j] == 0) {
					leastFact[j] = i;
				}
			}
		}
	}
	FreePow = pCur = &(powFracts[0]);
	for(i = 1; i < MAX_PRIMES ; i++){
		pPrev = pCur; pCur++; pPrev->pNext = pCur;
		pCur->pNext = NULL;
	}
	inFract.pFirst = inFract.pLast = NULL;
	inFract.firstPrime = inFract.lastPrime = 0;
	workFract.pFirst = workFract.pLast = NULL;
	workFract.firstPrime = workFract.lastPrime = 0;
	outFract.pFirst = outFract.pLast = NULL;
	outFract.firstPrime = outFract.lastPrime = 0;
	valFract.pFirst = valFract.pLast = NULL;
	valFract.firstPrime = valFract.lastPrime = 0;
	mask = 0xfff0000000000000;
}

int AddPrimePow(PPOW_FRACT pFract, int prime, short pow, int which)
{
	PPPOWFRACT pPrev, pCur, pNew;
	int diff, other = 1 - which;

	if((pNew = NewPowFract()) == NULL) {
		return -1;
	}
	pNew->pNext = pNew->pPrev = NULL;
	pNew->prime = prime;
	pNew->pows[which] = pow;
	pNew->pows[other] = 0;
	if(pFract->pFirst == NULL) {	// empty
		pFract->pFirst = pFract->pLast = pNew;
		pFract->firstPrime = pFract->lastPrime = prime;
	} else if(pFract->firstPrime > prime) {
		pNew->pNext = pFract->pFirst;
		pFract->pFirst->pPrev = pNew;
		pFract->pFirst = pNew;
		pFract->firstPrime = prime;
	} else if(pFract->lastPrime < prime) {
		pNew->pPrev = pFract->pLast;
		pFract->pLast->pNext = pNew;
		pFract->pLast = pNew;
		pFract->lastPrime = prime;
	} else {
		pPrev = NULL;
		pCur = pFract->pFirst;
		while(pCur->prime < prime) {
			pPrev = pCur; pCur = pCur->pNext;
		}
		if(pCur->prime == prime) { // add to current and check for cancel
			pCur->pows[which] += pow;
			ReleasePowFract(pNew);
			if(pCur->pows[other] != 0) {
				diff = pCur->pows[which]- pCur->pows[other];
				if(diff == 0) { // release pCur
					if(pCur->pNext == NULL) {
						if(pCur->pPrev == NULL) {
							pFract->pFirst = pFract->pLast = NULL;
							pFract->firstPrime = pFract->lastPrime = 0;
						} else {
							pNew = pCur->pPrev;
							pFract->pLast = pNew;
							pNew->pNext = NULL;
							pFract->lastPrime = pNew->prime;
						}
					} else if(pCur->pPrev == NULL) {
						pNew = pCur->pNext;
						pFract->pFirst = pNew;
						pNew->pPrev = NULL;
						pFract->firstPrime = pNew->prime;
					} else {
						pCur->pPrev->pNext = pCur->pNext;
						pCur->pNext->pPrev = pCur->pPrev;
					}
					ReleasePowFract(pCur);
				} else if(diff > 0) {
					pCur->pows[which] = diff;
					pCur->pows[other] = 0;
				} else {
					pCur->pows[which] = 0;
					pCur->pows[other] = -diff;
				}
			}
		} else { // link it in
			pNew->pNext = pCur;
			pCur->pPrev = pNew;
			if(pPrev == NULL) {
				pFract->pFirst = pNew;
			} else {
				pPrev->pNext = pNew;
			}
			pNew->pPrev = pPrev;
		}
	}

	return 0;
}

int AddPrimePowFactors(PPOW_FRACT pFract, int val, int which)
{
	int prime, rem;
	short pow;
	rem = val;
	while(rem > 1) {
		prime = leastFact[rem];
		pow = 1;
		rem /= prime;
		while((rem % prime) == 0) {
			rem  /= prime;
			pow++;
		}
		if(AddPrimePow(pFract, prime, pow, which) != 0) {
			return -1;
		}
	}
	return 0;
}

void DumpPowFract(PPOW_FRACT pFract, char *label)
{
#ifdef DEBUG
	PPPOWFRACT pCur;
	printf("%s:\n", label);
	pCur = pFract->pFirst;
	while(pCur != NULL) {
		if(pCur->pows[NUM] > 0) {
			printf("%d^%d\t", pCur->prime, pCur->pows[NUM]);
		}
		pCur = pCur->pNext;
	}
	printf("\n");
	pCur = pFract->pFirst;
	while(pCur != NULL) {
		if(pCur->pows[DEN] > 0) {
			printf("%d^%d\t", pCur->prime, pCur->pows[DEN]);
		}
		pCur = pCur->pNext;
	}
	printf("\n");
#endif
}

int CopyPowFract(PPOW_FRACT pFractSrc, PPOW_FRACT pFractDest)
{
	PPPOWFRACT pCur, pPrev, pNew;
	if(pFractDest->pFirst != NULL) {
		pCur = pFractDest->pFirst;
		while(pCur!= NULL) {
			pPrev = pCur;
			pCur = pCur->pNext;
			ReleasePowFract(pPrev);
		}
	}
	pFractDest->firstPrime = pFractSrc->firstPrime;
	pFractDest->lastPrime = pFractSrc->lastPrime;
	pCur = pFractSrc->pFirst;
	pPrev = NULL;
	while(pCur!= NULL) {
		if((pNew  = NewPowFract()) == NULL) {
			return -1;
		}
		pNew->prime = pCur->prime;
		pNew->pows[0] = pCur->pows[0];
		pNew->pows[1] = pCur->pows[1];
		pNew->pNext = NULL;
		if(pPrev == NULL) {
			pFractDest->pFirst = pNew;
		} else {
			pPrev->pNext = pNew;
		}
		pNew->pPrev = pPrev;
		pPrev = pNew;
		pCur = pCur->pNext;
	}
	pFractDest->pLast = pNew;
	return 0;
}

int FindPhiFactors()
{
	PPPOWFRACT pCur, pPrev, pNew;
	int prime, which, other;
	short pow;
	pCur = workFract.pLast;
	while( pCur != NULL) {
		prime = pCur->prime;
		pPrev = pCur->pPrev;
		if(pCur->pows[0] > 0) {
			pow = pCur->pows[0];
			which = 0;
		}
		else {
			pow = pCur->pows[1];
			which = 1;
		}
		other = 1 - which;
		if(pPrev == NULL) {
			workFract.pFirst = workFract.pLast = NULL;
			workFract.firstPrime = workFract.lastPrime = 0;
		} else {
			pPrev->pNext = NULL;
			workFract.pLast = pPrev;
			workFract.lastPrime = pPrev->prime;
		}
		if(pow & 1) {
			pCur->pows[which] = (pow+1)/2;
			pCur->pows[other] = 0;
		} else {
			pCur->pows[which] = (pow/2)+1;
			pCur->pows[other] = 1;
		}
		if((pNew = outFract.pFirst) == NULL) {
			outFract.pLast = pCur;
			outFract.lastPrime = prime;
			pCur->pNext = NULL;
		} else {
			pCur->pNext = pNew;
			pNew->pPrev = pCur;
		}
		pCur->pPrev = NULL;
		outFract.pFirst = pCur;
		outFract.firstPrime = prime;

		if(pow & 1) {
			if(AddPrimePowFactors(&workFract, prime - 1, other) != 0) {
				return -10;
			}
		}
		pCur = workFract.pLast;
		DumpPowFract(&workFract, "work");
		DumpPowFract(&outFract, "out");
	}
	return 0;
}

int CompResultVals()
{
	DDWORD t;
	PPPOWFRACT pCur;
	int pow;
	m = n = 1;
	pCur = outFract.pFirst;
	while(pCur != NULL) {
		t = pCur->prime;
		pow = pCur->pows[0];
		while(pow > 0) {
			m *= t; pow--;
			if(m & mask) {
				fprintf(stderr, "m %llu overflow on prime %llu\n", m, t);
				return -1;
			}
		}
		pow = pCur->pows[1];
		while(pow > 0) {
			n *= t; pow--;
			if(n & mask) {
				fprintf(stderr, "n %llu overflow on prime %llu\n", n, t);
				return -2;
			}
		}
		pCur = pCur->pNext;
	}
	return 0;
}

int Validate()
{
	PPPOWFRACT pCur, pPrev;
	int prime, which, other, a1, b1, t;
	short pow;
	if(CopyPowFract(&outFract, &workFract) != 0) {
		fprintf(stderr, "failed to copy out to work\n");
		return -11;
	}
	pCur = workFract.pLast;
	while( pCur != NULL) {
		prime = pCur->prime;
		pPrev = pCur->pPrev;
		if((pCur->pows[0]) == pCur->pows[1]) {
			fprintf(stderr, "same power %d for prime %d\n", pow, prime);
			return -12;
		}
		if((pCur->pows[0] > 1) && (pCur->pows[1] > 1)) {
			fprintf(stderr, "both powers for for prime %d > 1\n", prime);
			return -13;
		}
		if((pCur->pows[0]) > pCur->pows[1]) {
			pow = pCur->pows[0];
			which = 0;
		}
		else {
			pow = pCur->pows[1];
			which = 1;
		}
		other = 1 - which;
		if(pPrev == NULL) {
			workFract.pFirst = workFract.pLast = NULL;
			workFract.firstPrime = workFract.lastPrime = 0;
		} else {
			pPrev->pNext = NULL;
			workFract.pLast = pPrev;
			workFract.lastPrime = pPrev->prime;
		}
		ReleasePowFract(pCur);
		if(pCur->pows[other] > 0) {
			pow = 2*pow -2;
		} else {
			pow = 2*pow - 1;
		}
		if(AddPrimePow(&valFract, prime, pow, which) != 0) {
			fprintf(stderr, "add prime %d pow %d failed\n",
				prime, pow);
			return -9;
		}
		if(pow & 1) {
			if(AddPrimePowFactors(&valFract, prime - 1, which) != 0) {
				fprintf(stderr, "add prime -1 failed prime %d\n",
					prime);
				return -10;
			}
		}
		pCur = workFract.pLast;
		DumpPowFract(&workFract, "work");
		DumpPowFract(&valFract, "val");
	}
	pCur = valFract.pFirst;
	pPrev = inFract.pFirst;
	while((pCur != NULL) && (pPrev != NULL)) {
		if(pCur->prime != pPrev->prime) {
			fprintf(stderr, "val prime %d != in prime %d\n",
				pCur->prime, pPrev->prime);
			return -14;
		}
		if(pCur->pows[0] != pPrev->pows[0]) {
			fprintf(stderr, "val num pow %d != in num pow %d\n",
				pCur->pows[0], pPrev->pows[0]);
			return -15;
		}
		if(pCur->pows[1] != pPrev->pows[1]) {
			fprintf(stderr, "val den pow %d != in den pow %d\n",
				pCur->pows[1], pPrev->pows[1]);
			return -16;
		}
		pCur = pCur->pNext;
		pPrev = pPrev->pNext;
	}
	if(pCur != NULL) {
		fprintf(stderr, "extra val prime %d\n", pCur->prime);
		return -17;
	}
	if(pPrev != NULL) {
		fprintf(stderr, "extra in prime %d\n", pPrev->prime);
		return -18;
	}
	a1 = b1 = 1;
	pCur= valFract.pFirst;
	while(pCur != NULL) {
		t = pCur->prime;
		pow = pCur->pows[0];
		while(pow > 0) {
			a1 *= t; pow--;
		}
		pow = pCur->pows[1];
		while(pow > 0) {
			b1 *= t; pow--;
		}
		pCur = pCur->pNext;
	}
	if((a1 != a) || (b1 != b)) {
		fprintf(stderr, "a1 %d != a %d OR b1 %d != b %d\n", a1, a, b1, b);
		return -21;
	}
	return 0;
}

char inbuf[2048];
int main()
{
	int c;
	if(fgets(&(inbuf[0]), 2048, stdin) == NULL) {
		fprintf(stderr, "read failed on input\n");
		return -1;
	}
	if(sscanf(&(inbuf[0]), "%d %d", &a, &b) != 2) {
		fprintf(stderr, "scan failed on input\n");
		return -2;
	}
	if((a < 1) || (a > MAX_INPUT) || (b < 1) || (b > MAX_INPUT)) {
		fprintf(stderr, "a %d and/or b %d not in range 1...%d\n", 
			a, b, MAX_INPUT);
		return -3;
	}
	c = GCD(a, b);
	if(c > 1) {
		fprintf(stderr, "a, b not relatively prime\n");
		return -10;
	}
	if((a == 1) && (b == 1)) {
		printf("1 1\n");
		return 0;
	}
	if(a < b) maxin = b;
	else maxin = a;
	FactorSetup();
	if(AddPrimePowFactors(&inFract, a, NUM) != 0) {
		return -2;
	}
	if(AddPrimePowFactors(&inFract, b, DEN) != 0) {
		return -3;
	}
	DumpPowFract(&inFract, "input");
	if(CopyPowFract(&inFract, &workFract) != 0) {
		return -4;
	}
	DumpPowFract(&workFract, "work");
	if(FindPhiFactors() != 0) {
		return -5;
	}
	DumpPowFract(&outFract, "out");
	if(Validate() != 0) {
		DumpPowFract(&inFract, "in");
		return -20;
	}
	CompResultVals();
	printf("%llu %llu\n", m, n);
	return 0;
}

